@@ -1,9 +1,4 @@
 /* ============================================================
- *
- * This file is part of the KDE project
- *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
  *
  * SPDX-FileCopyrightText: 2007-2008 Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2009 Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
@@ -71,8 +66,7 @@ KSaneDeviceDialog::KSaneDeviceDialog(QWidget *parent)
     m_btnOk = bottomButtonBox->button(QDialogButtonBox::Ok);
     m_btnReloadDevices = bottomButtonBox->addButton(i18n("Reload devices list"), QDialogButtonBox::ButtonRole::ActionRole);
     layout->addWidget(bottomButtonBox);
-    //connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    //connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
     connect(bottomButtonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(bottomButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(m_btnReloadDevices, &QPushButton::clicked, this, &KSaneDeviceDialog::reloadDevicesList);
@@ -81,9 +75,6 @@ KSaneDeviceDialog::KSaneDeviceDialog(QWidget *parent)
     topLayout->addWidget(bottomButtonBox);
 
     setMinimumHeight(200);
-    m_findDevThread = FindSaneDevicesThread::getInstance();
-
-    connect(m_findDevThread, &FindSaneDevicesThread::finished, this, &KSaneDeviceDialog::updateDevicesList);
 
     reloadDevicesList();
 }
@@ -101,9 +92,7 @@ void KSaneDeviceDialog::reloadDevicesList()
     m_gbDevices->layout()->itemAt(0)->widget()->hide();  // explanation
     m_btnReloadDevices->setEnabled(false);
 
-    if (!m_findDevThread->isRunning()) {
-        m_findDevThread->start();
-    }
+    Q_EMIT requestReloadList();
 }
 
 void KSaneDeviceDialog::setAvailable(bool isAvailable)
@@ -129,11 +118,10 @@ QString KSaneDeviceDialog::getSelectedName() const
     return QString();
 }
 
-void KSaneDeviceDialog::updateDevicesList()
+void KSaneDeviceDialog::updateDevicesList(const QList<KSaneCore::DeviceInfo> &list)
 {
     qDeleteAll(m_btnGroupDevices->buttons());
 
-    const QList<KSaneWidget::DeviceInfo> list = m_findDevThread->devicesList();
     if (list.isEmpty()) {
         m_gbDevices->setTitle(i18n("Sorry. No devices found."));
         m_gbDevices->layout()->itemAt(0)->widget()->show();  // explanation
